@@ -3,17 +3,17 @@ library(testthat)
 library(webmockr)
 library(archiveRetriever)
 
-#Several tests are skipped_on_cran as they require an internet connection and it is always possible that the Internet Archive might be inaccessible at times. The tests do run successfully on our machines and were originally run on Cran using mock files with the vcr package. As the testing environment with vcr is not working at the moment due to problems with the package vcr, we are working towards a new solution to run our tests with mock files and will update our testing environment as soon as possible!
 
 #Check whether function output is data frame
 test_that("scrape_urls() returns a data frame", {
-  skip_on_cran()
+  vcr::use_cassette("scrape_url1", {
     output <-
       scrape_urls(
         "http://web.archive.org/web/20190502052859/http://www.taz.de/Praesident-Trong-scheut-Oeffentlichkeit/!5588752/",
         Paths = c(title = "//article//h1", content = "//article//p[contains(@class, 'article')]//text()"),
         encoding = "bytes"
       )
+  })
     expect_is(output, "data.frame")
   })
 
@@ -39,6 +39,18 @@ test_that("scrape_urls() only takes character vectors as Paths", {
   )
 })
 
+#Check whether collapse is logical
+test_that("scrape_urls() collapse must be logical", {
+  expect_error(
+    scrape_urls(
+      "http://web.archive.org/web/20201009174440/https://www.uni-mannheim.de/universitaet/profil/geschichte/",
+      c(title = "//h1"),
+        collapse = 5
+    ),
+    "collapse is not a logical value"
+  )
+})
+
 
 #Check whether XPath vector is named
 test_that("scrape_urls() only takes named XPath/CSS vector as Paths", {
@@ -53,7 +65,7 @@ test_that("scrape_urls() only takes named XPath/CSS vector as Paths", {
 
 #Check whether Archive date is taken from the URL
   test_that("scrape_urls() option archiveDate stores archiving date", {
-    skip_on_cran()
+    vcr::use_cassette("scrape_url2", {
     output <-
       scrape_urls(
         "http://web.archive.org/web/20170125090337/http://www.ilsole24ore.com/art/motori/2017-01-23/toyota-yaris-205049.shtml?uuid=AEAqSFG&nmll=2707",
@@ -67,18 +79,20 @@ test_that("scrape_urls() only takes named XPath/CSS vector as Paths", {
       archiveDate = TRUE,
       encoding = "bytes"
     )
+    })
     expect_equal(names(output)[4], "archiveDate")
   })
 
 #Check whether function takes CSS instead of XPath
   test_that("scrape_urls() takes CSS instead of XPath", {
-    skip_on_cran()
+    vcr::use_cassette("scrape_url3", {
     output <-
       scrape_urls(
         "http://web.archive.org/web/20190528072311/https://www.taz.de/Fusionsangebot-in-der-Autobranche/!5598075/",
         Paths = c(title = "article h1"),
         CSS = TRUE
       )
+    })
     expect_is(output, "data.frame")
   })
 
@@ -294,9 +308,10 @@ test_that("scrape_urls() needs encoding to be a character value", {
   )
 })
 
+
 #Check whether data is being correctly attached to existing data set
   test_that("scrape_urls() needs to start with second row when startnum is 2", {
-    skip_on_cran()
+    vcr::use_cassette("scrape_url4", {
     output <-
       scrape_urls(
         c(
@@ -306,6 +321,7 @@ test_that("scrape_urls() needs encoding to be a character value", {
         c(title = "//header//h1"),
         startnum = 2
       )
+    })
     expect_equal(output$Urls[1], "http://web.archive.org/web/20201009174440/https://www.uni-mannheim.de/universitaet/profil/geschichte/")
   })
 
@@ -326,7 +342,7 @@ test_that("scrape_urls() needs to warn if only some XPaths can be scraped", {
 
 #Check whether data is being correctly processed
   test_that("scrape_urls() needs to set NA if page cannot be scraped", {
-    skip_on_cran()
+    vcr::use_cassette("scrape_url5", {
     output <-
       scrape_urls(
         c(
@@ -336,6 +352,7 @@ test_that("scrape_urls() needs to warn if only some XPaths can be scraped", {
         ),
         Paths = c(title = "//article//h1", content = "//article//p[contains(@class, 'article')]//text()")
       )
+    })
     expect_equal(is.na(output$title[3]), TRUE)
   })
 
@@ -428,7 +445,7 @@ test_that("scrape_urls() should not take up process if it stems from other proce
 
 #Check whether sleeper is activated after 20 Urls
   test_that("scrape_urls() needs to sleep every 20 Urls", {
-    skip_on_cran()
+    vcr::use_cassette("scrape_url6", {
     output <-
       scrape_urls(
         c(
@@ -456,6 +473,7 @@ test_that("scrape_urls() should not take up process if it stems from other proce
         ),
         c(title = "//header//h1")
       )
+    })
     expect_equal(nrow(output), 21)
   })
 
@@ -492,12 +510,12 @@ test_that("scrape_urls() should not fail if website has timeout", {
 
 #Check whether new content is being correctly attached to existing object
   test_that("scrape_urls() needs to output 4 rows", {
-    skip_on_cran()
     input <-
       data.frame(Urls = c("http://web.archive.org/web/20171112174048/http://reddit.com:80/r/de", "http://web.archive.org/web/20171115220704/https://reddit.com/r/de"),
                  title = c("Der Frauen höchstes Glück ist das stillen des Hungers", "Am besten mit Frankfurter Kranz."),
                  author = c("Wilhelm_Blumberg", "NebuKadneZaar"),
                  stoppedat = 3)
+    vcr::use_cassette("scrape_url7", {
     output <-
       scrape_urls(
         c(
@@ -511,7 +529,60 @@ test_that("scrape_urls() should not fail if website has timeout", {
                   author = "(//p[contains(@class,'tagline')]/a | //div[contains(@class,'scrollerItem')]//a[starts-with(.,'u/')]/text() | //div[contains(@class,'NAURX0ARMmhJ5eqxQrlQW')]//span)"),
         startnum = 4,
         attachto = input)
-
+    })
     expect_equal(nrow(output), 4)
   })
 
+
+#Check whether script runs without problems when collapse is TRUE
+  test_that("scrape_urls() needs to output 1 row", {
+    skip_on_cran()
+    output <-
+      scrape_urls(Urls = "http://web.archive.org/web/20201216060059/https://www.reddit.com/r/de/",
+                  Paths = c(title = "//div/h3",
+                            type = "//div[@class='rpBJOHq2PR60pnwJlUyP0']//a//div[contains(@class,'2X6EB3ZhEeXCh1eIVA64XM')]/span"),
+                  collapse = TRUE)
+    expect_equal(nrow(output), 1)
+})
+
+
+#Check whether number of elements for paths differs
+test_that("scrape_urls() needs the number of elements for paths to be equal", {
+  skip_on_cran()
+   expect_warning(
+     output <- scrape_urls(Urls = "http://web.archive.org/web/20201216060059/https://www.reddit.com/r/de/",
+                 Paths = c(title = "//div/h3",
+                           type = "//div[@class='rpBJOHq2PR60pnwJlUyP0']//a//div[contains(@class,'2X6EB3ZhEeXCh1eIVA64XM')]/span"),
+                 collapse = FALSE,
+                ignoreErrors = FALSE
+     ),
+     "Number of elements for paths differs"
+   )
+   expect_is(output, "data.frame")
+})
+
+
+#Check whether script runs without problems when collapse & ignoreErrors is TRUE
+test_that("scrape_urls() needs to output 1 row", {
+  skip_on_cran()
+  output <-
+    scrape_urls(Urls = "http://web.archive.org/web/20201216060059/https://www.reddit.com/r/de/",
+                Paths = c(title = "//div/h3",
+                          type = "//div[@class='rpBJOHq2PR60pnwJlUyP0']//a//div[contains(@class,'2X6EB3ZhEeXCh1eIVA64XM')]/span"),
+                collapse = TRUE,
+                ignoreErrors = TRUE)
+  expect_equal(nrow(output), 1)
+})
+
+
+#Check whether script runs without problems when collapse & ignoreErrors is FALSE
+test_that("scrape_urls() needs to output 5 rows", {
+  skip_on_cran()
+  output <-
+    scrape_urls(Urls = "http://web.archive.org/web/20201230202327/https://www.reddit.com/r/de/",
+                Paths = c(title = "(//p[@class='title']/a | //div//a/h2 | //div//h3)",
+                          type = "//div[@class='rpBJOHq2PR60pnwJlUyP0']//a//div[contains(@class,'2X6EB3ZhEeXCh1eIVA64XM')]/span"),
+                collapse = FALSE,
+                ignoreErrors = FALSE)
+  expect_equal(nrow(output), 5)
+})
